@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.4.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.4.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -67,8 +71,8 @@
 #define yynerrs         urj_vhdl_nerrs
 
 
-/* Copy the first part of user declarations.  */
-#line 127 "vhdl_bison.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 127 "vhdl_bison.y"
 
 #include <stdlib.h>
 #include <string.h>
@@ -131,13 +135,17 @@ static void set_attr_string (urj_vhdl_parser_priv_t *, char *, char *);
 
 void yyerror (urj_vhdl_parser_priv_t *, const char *);
 
-#line 135 "vhdl_bison.c" /* yacc.c:339  */
+#line 139 "vhdl_bison.c"
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -149,8 +157,8 @@ void yyerror (urj_vhdl_parser_priv_t *, const char *);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "y.tab.h".  */
+/* Use api.header.include to #include this header
+   instead of duplicating it here.  */
 #ifndef YY_URJ_VHDL_VHDL_BISON_H_INCLUDED
 # define YY_URJ_VHDL_VHDL_BISON_H_INCLUDED
 /* Debug traces.  */
@@ -328,17 +336,16 @@ extern int urj_vhdl_debug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 191 "vhdl_bison.y" /* yacc.c:355  */
+#line 191 "vhdl_bison.y"
 
   int   integer;
   char *str;
 
-#line 340 "vhdl_bison.c" /* yacc.c:355  */
-};
+#line 347 "vhdl_bison.c"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -350,9 +357,7 @@ int urj_vhdl_parse (urj_vhdl_parser_priv_t *priv_data);
 
 #endif /* !YY_URJ_VHDL_VHDL_BISON_H_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 356 "vhdl_bison.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -373,13 +378,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -391,7 +396,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -427,15 +432,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -443,7 +439,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -463,6 +459,8 @@ typedef short int yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -605,16 +603,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  328
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   335
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -1008,22 +1006,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (priv_data, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (priv_data, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -1063,38 +1061,40 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, urj_vhdl_parser_priv_t *priv_data)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, urj_vhdl_parser_priv_t *priv_data)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (priv_data);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YYUSE (yytype);
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, urj_vhdl_parser_priv_t *priv_data)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, urj_vhdl_parser_priv_t *priv_data)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, priv_data);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, priv_data);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -1128,7 +1128,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, urj_vhdl_parser_priv_t *priv_data)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1139,7 +1139,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, urj_vhdl_parse
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , priv_data);
       YYFPRINTF (stderr, "\n");
     }
@@ -1243,7 +1243,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1261,7 +1264,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1339,10 +1342,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1354,6 +1357,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1365,9 +1369,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1498,23 +1503,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1530,14 +1545,10 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1553,35 +1564,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
-
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1639,7 +1648,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1654,7 +1662,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1674,513 +1682,514 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 3:
-#line 230 "vhdl_bison.y" /* yacc.c:1646  */
+  case 3:
+#line 230 "vhdl_bison.y"
     { urj_vhdl_set_entity (priv_data, (yyvsp[-1].str)); }
-#line 1681 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1689 "vhdl_bison.c"
     break;
 
   case 4:
-#line 232 "vhdl_bison.y" /* yacc.c:1646  */
+#line 232 "vhdl_bison.y"
     {
                Print_Error (priv_data, _("Improper Entity declaration"));
                Print_Error (priv_data, _("Check if source file is BSDL"));
                BUMP_ERROR; YYABORT;     /* Probably not a BSDL source file */
              }
-#line 1691 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1699 "vhdl_bison.c"
     break;
 
   case 6:
-#line 243 "vhdl_bison.y" /* yacc.c:1646  */
+#line 243 "vhdl_bison.y"
     {
               Print_Error (priv_data, _("Syntax Error"));
               BUMP_ERROR; YYABORT;
             }
-#line 1700 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1708 "vhdl_bison.c"
     break;
 
   case 7:
-#line 249 "vhdl_bison.y" /* yacc.c:1646  */
+#line 249 "vhdl_bison.y"
     { free ((yyvsp[-1].str)); }
-#line 1706 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1714 "vhdl_bison.c"
     break;
 
   case 8:
-#line 251 "vhdl_bison.y" /* yacc.c:1646  */
+#line 251 "vhdl_bison.y"
     {
              Print_Error (priv_data, _("Syntax Error"));
              BUMP_ERROR; YYABORT;
            }
-#line 1715 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1723 "vhdl_bison.c"
     break;
 
   case 11:
-#line 261 "vhdl_bison.y" /* yacc.c:1646  */
+#line 261 "vhdl_bison.y"
     {
                         Print_Error (priv_data, _("Improper Port declaration"));
                         BUMP_ERROR; YYABORT;
                       }
-#line 1724 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1732 "vhdl_bison.c"
     break;
 
   case 14:
-#line 270 "vhdl_bison.y" /* yacc.c:1646  */
+#line 270 "vhdl_bison.y"
     { urj_vhdl_port_apply_port (priv_data); }
-#line 1730 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1738 "vhdl_bison.c"
     break;
 
   case 15:
-#line 273 "vhdl_bison.y" /* yacc.c:1646  */
+#line 273 "vhdl_bison.y"
     { urj_vhdl_port_add_name (priv_data, (yyvsp[0].str)); }
-#line 1736 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1744 "vhdl_bison.c"
     break;
 
   case 16:
-#line 275 "vhdl_bison.y" /* yacc.c:1646  */
+#line 275 "vhdl_bison.y"
     { urj_vhdl_port_add_name (priv_data, (yyvsp[0].str)); }
-#line 1742 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1750 "vhdl_bison.c"
     break;
 
   case 22:
-#line 280 "vhdl_bison.y" /* yacc.c:1646  */
+#line 280 "vhdl_bison.y"
     { urj_vhdl_port_add_bit (priv_data); }
-#line 1748 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1756 "vhdl_bison.c"
     break;
 
   case 24:
-#line 284 "vhdl_bison.y" /* yacc.c:1646  */
+#line 284 "vhdl_bison.y"
     { urj_vhdl_port_add_range (priv_data, (yyvsp[-2].integer), (yyvsp[0].integer)); }
-#line 1754 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1762 "vhdl_bison.c"
     break;
 
   case 25:
-#line 286 "vhdl_bison.y" /* yacc.c:1646  */
+#line 286 "vhdl_bison.y"
     { urj_vhdl_port_add_range (priv_data, (yyvsp[0].integer), (yyvsp[-2].integer)); }
-#line 1760 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1768 "vhdl_bison.c"
     break;
 
   case 30:
-#line 293 "vhdl_bison.y" /* yacc.c:1646  */
+#line 293 "vhdl_bison.y"
     {
                   Print_Error (priv_data, _("Error in Package declaration(s)"));
                   BUMP_ERROR; YYABORT;
                 }
-#line 1769 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1777 "vhdl_bison.c"
     break;
 
   case 31:
-#line 299 "vhdl_bison.y" /* yacc.c:1646  */
+#line 299 "vhdl_bison.y"
     {/* Parse Standard 1149.1 Package */
                   strcpy (priv_data->Package_File_Name, (yyvsp[0].str));
                   free ((yyvsp[0].str));
                 }
-#line 1778 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1786 "vhdl_bison.c"
     break;
 
   case 32:
-#line 304 "vhdl_bison.y" /* yacc.c:1646  */
+#line 304 "vhdl_bison.y"
     {
                   priv_data->Reading_Package = 1;
                   urj_vhdl_flex_switch_file (priv_data->scanner,
                                              priv_data->Package_File_Name);
                 }
-#line 1788 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1796 "vhdl_bison.c"
     break;
 
   case 33:
-#line 310 "vhdl_bison.y" /* yacc.c:1646  */
+#line 310 "vhdl_bison.y"
     {
                   priv_data->Reading_Package = 0;
                 }
-#line 1796 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1804 "vhdl_bison.c"
     break;
 
   case 34:
-#line 316 "vhdl_bison.y" /* yacc.c:1646  */
+#line 316 "vhdl_bison.y"
     { free ((yyvsp[-8].str)); free ((yyvsp[-2].str)); }
-#line 1802 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1810 "vhdl_bison.c"
     break;
 
   case 35:
-#line 318 "vhdl_bison.y" /* yacc.c:1646  */
+#line 318 "vhdl_bison.y"
     {
                      Print_Error (priv_data, _("Error in Standard Package"));
                      BUMP_ERROR; YYABORT;
                    }
-#line 1811 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1819 "vhdl_bison.c"
     break;
 
   case 38:
-#line 327 "vhdl_bison.y" /* yacc.c:1646  */
+#line 327 "vhdl_bison.y"
     { free ((yyvsp[-3].str)); }
-#line 1817 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1825 "vhdl_bison.c"
     break;
 
   case 39:
-#line 329 "vhdl_bison.y" /* yacc.c:1646  */
+#line 329 "vhdl_bison.y"
     { free ((yyvsp[-3].str)); }
-#line 1823 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1831 "vhdl_bison.c"
     break;
 
   case 40:
-#line 332 "vhdl_bison.y" /* yacc.c:1646  */
+#line 332 "vhdl_bison.y"
     { free ((yyvsp[-1].str)); }
-#line 1829 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1837 "vhdl_bison.c"
     break;
 
   case 43:
-#line 336 "vhdl_bison.y" /* yacc.c:1646  */
+#line 336 "vhdl_bison.y"
     {
                    Print_Error (priv_data, _("Error in Standard Declarations"));
                    BUMP_ERROR; YYABORT;
                  }
-#line 1838 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1846 "vhdl_bison.c"
     break;
 
   case 44:
-#line 342 "vhdl_bison.y" /* yacc.c:1646  */
+#line 342 "vhdl_bison.y"
     { free ((yyvsp[0].str)); }
-#line 1844 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1852 "vhdl_bison.c"
     break;
 
   case 48:
-#line 347 "vhdl_bison.y" /* yacc.c:1646  */
+#line 347 "vhdl_bison.y"
     {
                    Print_Error (priv_data, _("Error in Attribute type identification"));
                    BUMP_ERROR; YYABORT;
                  }
-#line 1853 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1861 "vhdl_bison.c"
     break;
 
   case 52:
-#line 357 "vhdl_bison.y" /* yacc.c:1646  */
+#line 357 "vhdl_bison.y"
     { free ((yyvsp[0].str)); }
-#line 1859 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1867 "vhdl_bison.c"
     break;
 
   case 53:
-#line 360 "vhdl_bison.y" /* yacc.c:1646  */
+#line 360 "vhdl_bison.y"
     { free ((yyvsp[0].str)); }
-#line 1865 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1873 "vhdl_bison.c"
     break;
 
   case 55:
-#line 363 "vhdl_bison.y" /* yacc.c:1646  */
+#line 363 "vhdl_bison.y"
     {
                    Print_Error (priv_data, _("Error in Type definition"));
                    BUMP_ERROR; YYABORT;
                  }
-#line 1874 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1882 "vhdl_bison.c"
     break;
 
   case 58:
-#line 372 "vhdl_bison.y" /* yacc.c:1646  */
+#line 372 "vhdl_bison.y"
     { free ((yyvsp[0].str)); }
-#line 1880 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1888 "vhdl_bison.c"
     break;
 
   case 59:
-#line 374 "vhdl_bison.y" /* yacc.c:1646  */
+#line 374 "vhdl_bison.y"
     { free ((yyvsp[0].str)); }
-#line 1886 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1894 "vhdl_bison.c"
     break;
 
   case 60:
-#line 377 "vhdl_bison.y" /* yacc.c:1646  */
+#line 377 "vhdl_bison.y"
     { free ((yyvsp[-1].str)); }
-#line 1892 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1900 "vhdl_bison.c"
     break;
 
   case 61:
-#line 379 "vhdl_bison.y" /* yacc.c:1646  */
+#line 379 "vhdl_bison.y"
     {
                    Print_Error (priv_data, _("Error in Bit definition"));
                    BUMP_ERROR; YYABORT;
                  }
-#line 1901 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1909 "vhdl_bison.c"
     break;
 
   case 64:
-#line 388 "vhdl_bison.y" /* yacc.c:1646  */
+#line 388 "vhdl_bison.y"
     { free ((yyvsp[-3].str)); free ((yyvsp[-1].str)); }
-#line 1907 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1915 "vhdl_bison.c"
     break;
 
   case 65:
-#line 390 "vhdl_bison.y" /* yacc.c:1646  */
+#line 390 "vhdl_bison.y"
     {
                    Print_Error (priv_data, _("Error in Record Definition"));
                    BUMP_ERROR; YYABORT;
                  }
-#line 1916 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1924 "vhdl_bison.c"
     break;
 
   case 69:
-#line 401 "vhdl_bison.y" /* yacc.c:1646  */
+#line 401 "vhdl_bison.y"
     { free ((yyvsp[-3].str)); }
-#line 1922 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1930 "vhdl_bison.c"
     break;
 
   case 70:
-#line 403 "vhdl_bison.y" /* yacc.c:1646  */
+#line 403 "vhdl_bison.y"
     {
                       Print_Error (priv_data, _("Error in defered constant"));
                       BUMP_ERROR; YYABORT;
                     }
-#line 1931 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1939 "vhdl_bison.c"
     break;
 
   case 73:
-#line 412 "vhdl_bison.y" /* yacc.c:1646  */
+#line 412 "vhdl_bison.y"
     { free ((yyvsp[-4].str)); free ((yyvsp[0].str)); }
-#line 1937 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1945 "vhdl_bison.c"
     break;
 
   case 75:
-#line 415 "vhdl_bison.y" /* yacc.c:1646  */
+#line 415 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in Package Body definition"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1946 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1954 "vhdl_bison.c"
     break;
 
   case 78:
-#line 425 "vhdl_bison.y" /* yacc.c:1646  */
+#line 425 "vhdl_bison.y"
     { free ((yyvsp[-7].str)); }
-#line 1952 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1960 "vhdl_bison.c"
     break;
 
   case 79:
-#line 427 "vhdl_bison.y" /* yacc.c:1646  */
+#line 427 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in Cell Constant definition"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1961 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1969 "vhdl_bison.c"
     break;
 
   case 83:
-#line 438 "vhdl_bison.y" /* yacc.c:1646  */
+#line 438 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in Cell Data Record"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1970 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1978 "vhdl_bison.c"
     break;
 
   case 94:
-#line 447 "vhdl_bison.y" /* yacc.c:1646  */
+#line 447 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in Cell_Type Function field"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1979 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1987 "vhdl_bison.c"
     break;
 
   case 99:
-#line 454 "vhdl_bison.y" /* yacc.c:1646  */
+#line 454 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in BScan_Inst Instruction field"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1988 "vhdl_bison.c" /* yacc.c:1646  */
+#line 1996 "vhdl_bison.c"
     break;
 
   case 107:
-#line 461 "vhdl_bison.y" /* yacc.c:1646  */
+#line 461 "vhdl_bison.y"
     {
                     Print_Error (priv_data, _("Error in Constant CAP data source field"));
                     BUMP_ERROR; YYABORT;
                   }
-#line 1997 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2005 "vhdl_bison.c"
     break;
 
   case 108:
-#line 467 "vhdl_bison.y" /* yacc.c:1646  */
+#line 467 "vhdl_bison.y"
     {/* Parse Standard 1149.1 Package */
                     strcpy(priv_data->Package_File_Name, (yyvsp[0].str));
                     free((yyvsp[0].str));
                    }
-#line 2006 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2014 "vhdl_bison.c"
     break;
 
   case 109:
-#line 472 "vhdl_bison.y" /* yacc.c:1646  */
+#line 472 "vhdl_bison.y"
     {
                      priv_data->Reading_Package = 1;
                      urj_vhdl_flex_switch_file (priv_data->scanner,
                                                 priv_data->Package_File_Name);
                    }
-#line 2016 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2024 "vhdl_bison.c"
     break;
 
   case 110:
-#line 478 "vhdl_bison.y" /* yacc.c:1646  */
+#line 478 "vhdl_bison.y"
     {
                      priv_data->Reading_Package = 0;
                    }
-#line 2024 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2032 "vhdl_bison.c"
     break;
 
   case 111:
-#line 484 "vhdl_bison.y" /* yacc.c:1646  */
+#line 484 "vhdl_bison.y"
     { free((yyvsp[-6].str)); free((yyvsp[-2].str)); }
-#line 2030 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2038 "vhdl_bison.c"
     break;
 
   case 112:
-#line 486 "vhdl_bison.y" /* yacc.c:1646  */
+#line 486 "vhdl_bison.y"
     {Print_Error(priv_data, _("Error in User-Defined Package declarations"));
                     BUMP_ERROR; YYABORT; }
-#line 2037 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2045 "vhdl_bison.c"
     break;
 
   case 115:
-#line 492 "vhdl_bison.y" /* yacc.c:1646  */
+#line 492 "vhdl_bison.y"
     {
                   Print_Error (priv_data, _("Unknown VHDL statement"));
                   BUMP_ERROR; YYABORT;
                 }
-#line 2046 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2054 "vhdl_bison.c"
     break;
 
   case 119:
-#line 505 "vhdl_bison.y" /* yacc.c:1646  */
+#line 505 "vhdl_bison.y"
     { free ((yyvsp[-5].str)); }
-#line 2052 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2060 "vhdl_bison.c"
     break;
 
   case 126:
-#line 515 "vhdl_bison.y" /* yacc.c:1646  */
+#line 515 "vhdl_bison.y"
     {
                          Print_Error (priv_data, _("Error in Attribute specification"));
                          BUMP_ERROR; YYABORT;
                        }
-#line 2061 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2069 "vhdl_bison.c"
     break;
 
   case 127:
-#line 521 "vhdl_bison.y" /* yacc.c:1646  */
+#line 521 "vhdl_bison.y"
     {
                        //set_attr_bool (priv_data, $1, $7);
                        //free ($3);
                        /* skip boolean attributes for the time being */
                        free ((yyvsp[-7].str)); free ((yyvsp[-5].str));
                      }
-#line 2072 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2080 "vhdl_bison.c"
     break;
 
   case 128:
-#line 529 "vhdl_bison.y" /* yacc.c:1646  */
+#line 529 "vhdl_bison.y"
     { (yyval.integer) = 1; }
-#line 2078 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2086 "vhdl_bison.c"
     break;
 
   case 129:
-#line 531 "vhdl_bison.y" /* yacc.c:1646  */
+#line 531 "vhdl_bison.y"
     { (yyval.integer) = 0; }
-#line 2084 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2092 "vhdl_bison.c"
     break;
 
   case 130:
-#line 534 "vhdl_bison.y" /* yacc.c:1646  */
+#line 534 "vhdl_bison.y"
     {
                       set_attr_decimal (priv_data, (yyvsp[-7].str), (yyvsp[-1].integer));
                       free ((yyvsp[-5].str));
                     }
-#line 2093 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2101 "vhdl_bison.c"
     break;
 
   case 131:
-#line 540 "vhdl_bison.y" /* yacc.c:1646  */
+#line 540 "vhdl_bison.y"
     {
                      //set_attr_real (priv_data, $1, $8);
                      //free ($3);
                      /* skip real attributes for the time being */
                      free ((yyvsp[-11].str)); free ((yyvsp[-9].str)); free ((yyvsp[-4].str));
                    }
-#line 2104 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2112 "vhdl_bison.c"
     break;
 
   case 134:
-#line 550 "vhdl_bison.y" /* yacc.c:1646  */
+#line 550 "vhdl_bison.y"
     {
                      set_attr_string (priv_data, (yyvsp[-7].str), strdup (priv_data->buffer));
                      free ((yyvsp[-5].str));
                    }
-#line 2113 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2121 "vhdl_bison.c"
     break;
 
   case 135:
-#line 556 "vhdl_bison.y" /* yacc.c:1646  */
+#line 556 "vhdl_bison.y"
     { free ((yyvsp[-7].str)); free ((yyvsp[-5].str)); }
-#line 2119 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2127 "vhdl_bison.c"
     break;
 
   case 136:
-#line 559 "vhdl_bison.y" /* yacc.c:1646  */
+#line 559 "vhdl_bison.y"
     {
                      Init_Text (priv_data);
                      Store_Text (priv_data, (yyvsp[0].str));
                      free ((yyvsp[0].str));
                    }
-#line 2129 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2137 "vhdl_bison.c"
     break;
 
   case 137:
-#line 565 "vhdl_bison.y" /* yacc.c:1646  */
+#line 565 "vhdl_bison.y"
     {
                      Store_Text (priv_data, (yyvsp[0].str));
                      free ((yyvsp[0].str));
                    }
-#line 2138 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2146 "vhdl_bison.c"
     break;
 
   case 138:
-#line 571 "vhdl_bison.y" /* yacc.c:1646  */
+#line 571 "vhdl_bison.y"
     {
                priv_data->Reading_Package = 1;
                urj_vhdl_flex_switch_file (priv_data->scanner,
                                           priv_data->Package_File_Name);
              }
-#line 2148 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2156 "vhdl_bison.c"
     break;
 
   case 139:
-#line 577 "vhdl_bison.y" /* yacc.c:1646  */
+#line 577 "vhdl_bison.y"
     {
                priv_data->Reading_Package = 0;
              }
-#line 2156 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2164 "vhdl_bison.c"
     break;
 
   case 140:
-#line 582 "vhdl_bison.y" /* yacc.c:1646  */
+#line 582 "vhdl_bison.y"
     {
                  strcpy (priv_data->Package_File_Name, "STD_1532_2001");
                }
-#line 2164 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2172 "vhdl_bison.c"
     break;
 
   case 141:
-#line 586 "vhdl_bison.y" /* yacc.c:1646  */
+#line 586 "vhdl_bison.y"
     {
                  strcpy (priv_data->Package_File_Name, "STD_1532_2002");
                }
-#line 2172 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2180 "vhdl_bison.c"
     break;
 
   case 143:
-#line 594 "vhdl_bison.y" /* yacc.c:1646  */
+#line 594 "vhdl_bison.y"
     {
                        priv_data->Reading_Package = 1;
                      }
-#line 2180 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2188 "vhdl_bison.c"
     break;
 
 
-#line 2184 "vhdl_bison.c" /* yacc.c:1646  */
+#line 2192 "vhdl_bison.c"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2205,14 +2214,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -2295,12 +2303,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -2362,6 +2368,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -2369,6 +2376,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -2379,6 +2387,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -2408,7 +2420,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 603 "vhdl_bison.y" /* yacc.c:1906  */
+#line 603 "vhdl_bison.y"
   /* End rules, begin programs  */
 /*****************************************************************************
  * void Init_Text( urj_vhdl_parser_priv_t *priv )
@@ -2727,9 +2739,8 @@ urj_vhdl_set_entity (urj_vhdl_parser_priv_t *priv, char *entityname)
 {
     if (priv->jtag_ctrl->proc_mode & URJ_BSDL_MODE_INSTR_EXEC)
     {
-        strncpy (priv->jtag_ctrl->part->part, entityname,
-                 URJ_PART_PART_MAXLEN);
-        priv->jtag_ctrl->part->part[URJ_PART_PART_MAXLEN] = '\0';
+        strncpy (priv->entity_name, entityname, VHDL_PARSER_ENTITY_NAME_MAXLEN);
+        priv->entity_name[VHDL_PARSER_ENTITY_NAME_MAXLEN] = '\0';
     }
 
     free (entityname);
